@@ -45,6 +45,7 @@ GetOptions (\%options,
                coverpage-only-if-toc
                include-path=s@
                purge
+               run-timeout=i
                help/) or die "Bad option passed!\n";
 
 if ($options{help}) {
@@ -195,6 +196,10 @@ compiling them accordingly to the options.
 
 No target files can be specified.
 
+=item --run-timeout INTEGER
+
+Set the latex/xindy max time execution in seconds.
+
 =item --dry-run
 
 For recursive compile, you can pass this option to just list the files
