@@ -143,6 +143,10 @@ As above, but only the sans fonts
 
 Return an arrayref with the default font definitions
 
+=head2 fonts_for_language($babel_lang)
+
+Return the list of language-specific fonts.
+
 =head1 INTERNALS
 
 =head2 BUILDARGS
@@ -194,6 +198,19 @@ sub mono_fonts_with_files {
     return grep { $_->is_mono && $_->has_files } @{$self->list};
 }
 
+sub fonts_for_language {
+    my ($self, $slot, $babel_lang) = @_;
+    die "Missing arguments" unless $slot && $babel_lang;
+    if ($slot eq 'main') {
+        $slot = 'serif';
+    }
+    # print Dumper([$self->all_fonts]);
+    return grep {
+        $_->type eq $slot and $_->has_languages and $_->for_babel_language($babel_lang)
+    } $self->all_fonts;
+}
+
+
 sub BUILDARGS {
     my ($class, $arg) = @_;
     my $list;
@@ -386,6 +403,54 @@ sub default_font_list {
             },
             { name => 'Anonymous Pro', desc => 'Anonymous Pro', type => 'mono' },
             { name => 'Space Mono',    desc => 'Space Mono',    type => 'mono' },
+            {
+             "languages" =>  [ "zh" ],
+             "name" =>  "Source Han Serif SC",
+             "desc" =>  "Source Han Serif SC (Simplified Chinese)",
+             "type" =>  "serif"
+            },
+            {
+             "languages" =>  [ "ja" ],
+             "name" =>  "Source Han Serif",
+             "desc" =>  "Source Han Serif (Japanese)",
+             "type" =>  "serif"
+            },
+            {
+             "languages" =>  [ "ko" ],
+             "name" =>  "Source Han Serif K",
+             "desc" =>  "Source Han Serif K (Korean)",
+             "type" =>  "serif"
+            },
+            {
+             "languages" =>  [ "zh" ],
+             "name" =>  "Source Han Sans SC",
+             "desc" =>  "Source Han Sans SC (Simplified Chinese)",
+             "type" =>  "sans"
+            },
+            {
+             "languages" =>  [ "ja" ],
+             "name" =>  "Source Han Sans",
+             "desc" =>  "Source Han Sans (Japanese)",
+             "type" =>  "sans"
+            },
+            {
+             "languages" =>  [ "ko" ],
+             "name" =>  "Source Han Sans K",
+             "desc" =>  "Source Han Sans K (Korean)",
+             "type" =>  "sans"
+            },
+            {
+             "languages" =>  [ "zh" ],
+             "name" =>  "FandolSong",
+             "desc" =>  "FandolSong",
+             "type" =>  "sans"
+            },
+            {
+             "languages" =>  [ "zh" ],
+             "desc" =>  "FandolHei",
+             "name" =>  "FandolHei",
+             "type" =>  "serif"
+            },
            ];
 }
 
